==> vortexpy-0.7.8.tar.gz: vortexpy-0.7.8/vortex/test/TupleTest.py <==
"""
 * Created by Synerty Pty Ltd
 *
 * This software is open source, the MIT license applies.
 *
 * Website : http://www.synerty.com
 * Support : support@synerty.com
"""

import datetime
import json

from lxml import etree
from twisted.trial import unittest

from FastXml import FastXml
from Tuple import TUPLE_TYPES_BY_NAME, TupleHash
from tuples_test.TestTuple import TestSubTuple, TestTuple

json.dump()

def makeTupleA():
    tuple_ = TestTuple()
    tuple_.aBoolTrue = True
    tuple_.aBoolFalse = False
    tuple_.aDate = datetime.datetime(2010, 4, 7, 2, 33, 19, 666)
    tuple_.aFloat = 2.56
    tuple_.aInt = 1231231
    tuple_.aString = 'test string from 345345345@$#%#$%#$%#$%#'
    tuple_.aSet = ['x', 2, False] # Sets are restored as Lists
    tuple_.aList = ['y', 3, True, 3.3]
    tuple_.aDict = {'a': 'test str', # Key strings are loaded as unicode
                    1: 1.234}

    subTuple = TestSubTuple()
    subTuple.subInt = 2048
    tuple_.aSubTuple = subTuple
    #
    tuple_.aListOfSubTuples = []
    for x in range(2):
        subTuple = TestSubTuple()
        subTuple.subInt = x
        tuple_.aListOfSubTuples.append(subTuple)

    return tuple_


class TuplePyTest(unittest.TestCase):
    PERFORMANCE_ITERATIONS = 10000

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTupleToFromXml(self):
        # Create document
        xmlDoc = FastXml()
        xmlParent = xmlDoc.createElement('test')
        xmlDoc.appendChild(xmlParent)

        # Create tuple
        origTuple = makeTupleA()

        # To XML
        origTuple.toXml(xmlDoc, xmlParent)
        xmlStr = xmlDoc.toPrettyXml()
        # print xmlStr


        doc = etree.fromstring(xmlStr)
        xmlDoc = doc.getroottree().getroot()
        xmlTuple = xmlDoc[0]

        tupleType = xmlTuple.attrib.get('t')
        Tuple_ = TUPLE_TYPES_BY_NAME[tupleType]
        deserialisedTuple = Tuple_().fromXml(xmlTuple)

        self.assertEqual(TupleHash(origTuple), TupleHash(origTuple))
        self.assertEqual(TupleHash(deserialisedTuple), TupleHash(deserialisedTuple))

        self.assertEqual(TupleHash(origTuple), TupleHash(deserialisedTuple),
                         'Tuple serialise -> deserialise error')

    def testTupleToFromJson(self):
        # Create tuple
        origTuple = makeTupleA()

        # To Json
        jsonDictStr = json.dumps(origTuple.toJsonDict())
        deserialisedTuple = TestTuple().fromJsonDict(json.loads(jsonDictStr))
        # print xmlStr

        self.assertEqual(TupleHash(origTuple), TupleHash(origTuple))
        self.assertEqual(TupleHash(deserialisedTuple), TupleHash(deserialisedTuple))

        # print TupleHash(origTuple)._key()
        # print TupleHash(deserialisedTuple)._key()

        self.assertEqual(TupleHash(origTuple), TupleHash(deserialisedTuple),
                         'Tuple serialise -> deserialise error')

    def testTupleToFromJsonPerformanceMulti(self):
        for _ in range(self.PERFORMANCE_ITERATIONS):
            origTuple = makeTupleA()
            jsonDictStr = json.dumps(origTuple.toJsonDict())
            TestTuple().fromJsonDict(json.loads(jsonDictStr))

    def testTupleToFromJsonPerformanceSingle(self):
        origTuple = makeTupleA()
        origTuple.aListOfSubTuples = [makeTupleA()
                                      for _ in range(self.PERFORMANCE_ITERATIONS)]
        jsonDictStr = json.dumps(origTuple.toJsonDict())
        TestTuple().fromJsonDict(json.loads(jsonDictStr))

    def testTupleToFromXmlPerformance(self):
        for x in range(self.PERFORMANCE_ITERATIONS):
            x = False and x
            self.testTupleToFromXml()

    def testTupleHash(self):
        hashA1 = TupleHash(makeTupleA())
        hashA2 = TupleHash(makeTupleA())
        print("hashA1 = %s" % hashA1.__hash__())
        print("hashA2 = %s" % hashA2.__hash__())

        hashB1 = TupleHash(makeTupleA())
        hashB1.tupl.aString = 'Not the same as the others'
        print("hashB1 = %s" % hashB1.__hash__())

        hashA1.__hash__()
        self.assertTrue(hashA1.__hash__() == hashA1.__hash__(),
                        'TupleHash A1.__hash__() == A1.__hash__()')

        self.assertTrue(hashA1 == hashA2, 'TupleHash __eq__ fail, A1 == A2')
        self.assertFalse(hashA1 != hashA2, 'TupleHash __ne__ fail, A1 != A2')
        self.assertFalse(hashA1 == hashB1, 'TupleHash __eq__ fail, A1 == B1')
        self.assertTrue(hashA1 != hashB1, 'TupleHash __ne__ fail, A1 != B1')

        self.assertTrue(hashA1 in {hashA2: None}, 'TupleHash in fail, A1 in {A2:None}')
        self.assertFalse(hashA1 not in {hashA2: None},
                         'TupleHash in fail, A1 not in {A2:None}')
        self.assertTrue(hashA1 not in {hashB1: None},
                        'TupleHash in fail, A1 not in {B1:None}')
        self.assertFalse(hashA1 in {hashB1: None}, 'TupleHash in fail, A1 in {B1:None}')

==> vortexpy-1.2.15.tar.gz: vortexpy-1.2.15/vortex/test/TupleTest.py <==
"""
 * Created by Synerty Pty Ltd
 *
 * This software is open source, the MIT license applies.
 *
 * Website : http://www.synerty.com
 * Support : support@synerty.com
"""

import datetime
import json

from twisted.trial import unittest

from vortex.Tuple import TUPLE_TYPES_BY_NAME, TupleHash
from vortex.test.TestTuple import TestSubTuple, TestTuple


def makeTupleA():
    tuple_ = TestTuple()
    tuple_.aBoolTrue = True
    tuple_.aBoolFalse = False
    tuple_.aDate = datetime.datetime(2010, 4, 7, 2, 33, 19, 666)
    tuple_.aFloat = 2.56
    tuple_.aInt = 1231231
    tuple_.aString = 'test string from 345345345@$#%#$%#$%#$%#'
    tuple_.aSet = ['x', 2, False] # Sets are restored as Lists
    tuple_.aList = ['y', 3, True, 3.3]
    tuple_.aDict = {'a': 'test str', # Key strings are loaded as unicode
                    1: 1.234}

    subTuple = TestSubTuple()
    subTuple.subInt = 2048
    tuple_.aSubTuple = subTuple
    #
    tuple_.aListOfSubTuples = []
    for x in range(2):
        subTuple = TestSubTuple()
        subTuple.subInt = x
        tuple_.aListOfSubTuples.append(subTuple)

    return tuple_


class TuplePyTest(unittest.TestCase):
    PERFORMANCE_ITERATIONS = 10000

    def setUp(self):
        pass

    def tearDown(self):
        pass


    def testTupleToFromJson(self):
        # Create tuple
        origTuple = makeTupleA()

        # To Json
        jsonDictStr = json.dumps(origTuple.toJsonDict())
        deserialisedTuple = TestTuple().fromJsonDict(json.loads(jsonDictStr))
        # print xmlStr

        self.assertEqual(TupleHash(origTuple), TupleHash(origTuple))
        self.assertEqual(TupleHash(deserialisedTuple), TupleHash(deserialisedTuple))

        # print TupleHash(origTuple)._key()
        # print TupleHash(deserialisedTuple)._key()

        self.assertEqual(TupleHash(origTuple), TupleHash(deserialisedTuple),
                         'Tuple serialise -> deserialise error')

    def testTupleToFromJsonPerformanceMulti(self):
        for _ in range(self.PERFORMANCE_ITERATIONS):
            origTuple = makeTupleA()
            jsonDictStr = json.dumps(origTuple.toJsonDict())
            TestTuple().fromJsonDict(json.loads(jsonDictStr))

    def testTupleToFromJsonPerformanceSingle(self):
        origTuple = makeTupleA()
        origTuple.aListOfSubTuples = [makeTupleA()
                                      for _ in range(self.PERFORMANCE_ITERATIONS)]
        jsonDictStr = json.dumps(origTuple.toJsonDict())
        TestTuple().fromJsonDict(json.loads(jsonDictStr))



    def testTupleHash(self):
        hashA1 = TupleHash(makeTupleA())
        hashA2 = TupleHash(makeTupleA())
        print("hashA1 = %s" % hashA1.__hash__())
        print("hashA2 = %s" % hashA2.__hash__())

        hashB1 = TupleHash(makeTupleA())
        hashB1.tupl.aString = 'Not the same as the others'
        print("hashB1 = %s" % hashB1.__hash__())

        hashA1.__hash__()
        self.assertTrue(hashA1.__hash__() == hashA1.__hash__(),
                        'TupleHash A1.__hash__() == A1.__hash__()')

        self.assertTrue(hashA1 == hashA2, 'TupleHash __eq__ fail, A1 == A2')
        self.assertFalse(hashA1 != hashA2, 'TupleHash __ne__ fail, A1 != A2')
        self.assertFalse(hashA1 == hashB1, 'TupleHash __eq__ fail, A1 == B1')
        self.assertTrue(hashA1 != hashB1, 'TupleHash __ne__ fail, A1 != B1')

        self.assertTrue(hashA1 in {hashA2: None}, 'TupleHash in fail, A1 in {A2:None}')
        self.assertFalse(hashA1 not in {hashA2: None},
                         'TupleHash in fail, A1 not in {A2:None}')
        self.assertTrue(hashA1 not in {hashB1: None},
                        'TupleHash in fail, A1 not in {B1:None}')
        self.assertFalse(hashA1 in {hashB1: None}, 'TupleHash in fail, A1 in {B1:None}')
